smartcard.pyro.server.PyroDaemon.PyroDaemon

# ``smartcard`.`pyro`.`server`.`PyroDaemon`.`PyroDaemon``

class documentation

`class PyroDaemon(object):`

View In Hierarchy

Singleton class to wrap the pyro daemon.

Method | `__getattr__` | Undocumented
Method | `__init__` | Undocumented
Class Variable | `instance` | Undocumented
Class | `_PyroDaemon` | The pyro daemon actual wrapper class.

def __getattr__(self, name):

Undocumented

def __init__(self):

Undocumented

instance =

Undocumented